<?php

/**
 * Plugin Name: Affiliate Formidable Forms Integration
 * Plugin URI: https://www.tipsandtricks-hq.com/wordpress-affiliate/
 * Description: Integrates Affiliate Platform with Formidable Forms plugin.
 * Version: 1.2
 * Author: Tips and Tricks HQ
 * Author URI: https://www.tipsandtricks-hq.com/
 * Requires at least: 3.0
 */
if (!defined('ABSPATH')) {
    exit;
}

define('WPAP_FP_INT_PATH', plugin_dir_path(__FILE__));

include_once('affiliate-formidable-forms-admin.php');

add_action('frm_after_create_entry', 'wpap_formidable_lead_capture', 30, 2);

function wpap_formidable_lead_capture($entry_id, $form_id) {
    //Retrieve the addon options
    $addon_options = get_option('wpap_fp_int_settings');
    if ($addon_options) {
        $lead_capture_enabled = $addon_options['lead_capture_enabled'];
        $lc_form_exclusion = $addon_options['lc_form_exclusion'];
    }

    //Check if lead capture is enabled
    if (empty($lead_capture_enabled)) {
        return;
    }
    wp_affiliate_log_debug('Formidable form integration - Lead capture option is enabled.', true);

    //Check form exclusion list
    if (!empty($lc_form_exclusion)) {
        $form_exclusion_list = explode(",", $lc_form_exclusion);
        foreach ($form_exclusion_list as $excluded_form_id) {
            if ($form_id == trim($excluded_form_id)) {
                wp_affiliate_log_debug("You have excluded this form (ID: " . $form_id . " ) from the lead capture pool. So no lead will be captured for this submission.", true);
                return;
            }
        }
    }

    //View the entry or the form or post data using the following
    //$entry = FrmEntry::getOne($entry_id);
    //$form = FrmForm::getOne($form_id);
    //print_r($_POST);

    $email = '';
    $form_data = $_POST['item_meta'];
    foreach($form_data as $field_val){
        if(is_email($field_val)){
            //Email field value
            $email = $field_val;
            break;
        }
    }
    if(empty($email)){
        wp_affiliate_log_debug("Could not retrieve email field value from this submission. Cannot capture the lead.", false);
        return;
    }

    $reference = 'Form ID: '.$form_id;
    $name = '';

    $aff_id = wp_affiliate_get_referrer();
    $clientdate = (date("Y-m-d"));
    $clienttime = (date("H:i:s"));
    $ipaddress = wp_aff_get_user_ip();
    $debug_data = "Formidable Form lead capture data. Email: " . $email . " | Affiliate ID: " . $aff_id . " | Formidable Form ID: " . $form_id . " | Entry ID: " . $entry_id;
    wp_affiliate_log_debug($debug_data, true);
    if (!empty($aff_id)) {
        //Capture the lead in the database
        wp_aff_capture_lead_data_in_leads_table($email, $name, $aff_id, $reference, $clientdate, $clienttime, $ipaddress);
    } else {
        wp_affiliate_log_debug("Formidable Form lead capture result: This is not an affiliate referral.", true);
    }
}
